==> derby_10.10.2.0.orig.tar.xz: db-derby-10.10.2.0-src/java/testing/org/apache/derbyTesting/functionTests/tests/store/_Suite.java <==
/*

   Derby - Class org.apache.derbyTesting.functionTests.tests.store._Suite

       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
package org.apache.derbyTesting.functionTests.tests.store;

import org.apache.derbyTesting.junit.BaseTestCase;
import org.apache.derbyTesting.junit.JDBC;

import junit.framework.Test;  
import junit.framework.TestSuite;
import org.apache.derby.iapi.services.sanity.SanityManager;

/**
 * Suite to run all JUnit tests in this package:
 * org.apache.derbyTesting.functionTests.tests.lang
 * <P>
 * All tests are run "as-is", just as if they were run
 * individually. Thus this test is just a collection
 * of all the JUNit tests in this package (excluding itself).
 * While the old test harness is in use, some use of decorators
 * may be required.
 *
 */
public class _Suite extends BaseTestCase  {

    /**
     * Use suite method instead.
     */
    private _Suite(String name) {
        super(name);
    }

    public static Test suite() {

        TestSuite suite = new TestSuite("store");

        suite.addTest(BootAllTest.suite());
        suite.addTest(ClassLoaderBootTest.suite());
        suite.addTest(StreamingColumnTest.suite());
        suite.addTest(Derby3625Test.suite());
        suite.addTest(Derby4577Test.suite());
        suite.addTest(InterruptResilienceTest.suite());
        suite.addTest(Derby4676Test.suite());
        suite.addTest(BootLockTest.suite());
        suite.addTest(UpdateLocksTest.suite());
        suite.addTest(PositionedStoreStreamTest.suite());
        suite.addTest(OSReadOnlyTest.suite());
        suite.addTest(BackupRestoreTest.suite());
        suite.addTest(OfflineBackupTest.suite());
        suite.addTest(LiveLockTest.suite());
        suite.addTest(ClobReclamationTest.suite());
        suite.addTest(IndexSplitDeadlockTest.suite());
        suite.addTest(HoldCursorJDBC30Test.suite());
        suite.addTest(AccessTest.suite());
        suite.addTest(AutomaticIndexStatisticsTest.suite());
        suite.addTest(Derby5582AutomaticIndexStatisticsTest.suite());
        suite.addTest(AutomaticIndexStatisticsMultiTest.suite());
        suite.addTest(BTreeMaxScanTest.suite());
        suite.addTest(MadhareTest.suite());
        suite.addTest(LongColumnTest.suite());
        suite.addTest(RowLockBasicTest.suite());
        suite.addTest(RecoveryTest.suite());
        suite.addTest(OCRecoveryTest.suite());
        suite.addTest(TableLockBasicTest.suite());
        suite.addTest(ServicePropertiesFileTest.suite());
        suite.addTest(Derby5234Test.suite());
        suite.addTest(KeepDisposableStatsPropertyTest.suite());
        suite.addTest(LockTableVtiTest.suite());
        suite.addTest(StoreScriptsTest.suite());
        suite.addTest(Derby4923Test.suite());

        /* Tests that only run in sane builds */
        if (SanityManager.DEBUG) {
            suite.addTest(HoldCursorExternalSortJDBC30Test.suite());
        }

        // Encryption only supported for Derby in J2SE/J2EE environments.
        // J2ME (JSR169) does not support encryption.
        if (JDBC.vmSupportsJDBC3()) {
            // Add tests of basic functionality on encrypted databases.
            suite.addTest(EncryptionKeyAESTest.suite());
            suite.addTest(EncryptionKeyBlowfishTest.suite());
            suite.addTest(EncryptionKeyDESTest.suite());
            suite.addTest(EncryptionAESTest.suite());
            suite.addTest(EncryptDatabaseTest.suite());
            suite.addTest(CryptoCrashRecoveryTest.suite());
            suite.addTest(DecryptDatabaseTest.suite());
        }

        return suite;
    }
}

==> derby_10.14.2.0.orig.tar.xz: db-derby-10.14.2.0-src/java/testing/org/apache/derbyTesting/functionTests/tests/store/_Suite.java <==
/*

   Derby - Class org.apache.derbyTesting.functionTests.tests.store._Suite

       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
package org.apache.derbyTesting.functionTests.tests.store;

import junit.framework.Test;
import org.apache.derby.shared.common.sanity.SanityManager;
import org.apache.derbyTesting.junit.BaseTestCase;
import org.apache.derbyTesting.junit.BaseTestSuite;
import org.apache.derbyTesting.junit.JDBC;

/**
 * Suite to run all JUnit tests in this package:
 * org.apache.derbyTesting.functionTests.tests.lang
 * <P>
 * All tests are run "as-is", just as if they were run
 * individually. Thus this test is just a collection
 * of all the JUNit tests in this package (excluding itself).
 * While the old test harness is in use, some use of decorators
 * may be required.
 *
 */
public class _Suite extends BaseTestCase  {

    /**
     * Use suite method instead.
     */
    private _Suite(String name) {
        super(name);
    }

    public static Test suite() {

        BaseTestSuite suite = new BaseTestSuite("store");

        suite.addTest(BootAllTest.suite());
        suite.addTest(ClassLoaderBootTest.suite());
        suite.addTest(StreamingColumnTest.suite());
        suite.addTest(Derby3625Test.suite());
        suite.addTest(Derby4577Test.suite());
        suite.addTest(InterruptResilienceTest.suite());
        suite.addTest(Derby4676Test.suite());
        suite.addTest(BootLockTest.suite());
        suite.addTest(UpdateLocksTest.suite());
        suite.addTest(PositionedStoreStreamTest.suite());
        suite.addTest(OSReadOnlyTest.suite());
        suite.addTest(BackupRestoreTest.suite());
        suite.addTest(OfflineBackupTest.suite());
        suite.addTest(LiveLockTest.suite());
        suite.addTest(ClobReclamationTest.suite());
        suite.addTest(IndexSplitDeadlockTest.suite());
        suite.addTest(HoldCursorJDBC30Test.suite());
        suite.addTest(AccessTest.suite());
        suite.addTest(AutomaticIndexStatisticsTest.suite());
        suite.addTest(Derby5582AutomaticIndexStatisticsTest.suite());
        suite.addTest(AutomaticIndexStatisticsMultiTest.suite());
        suite.addTest(BTreeMaxScanTest.suite());
        suite.addTest(MadhareTest.suite());
        suite.addTest(LongColumnTest.suite());
        suite.addTest(RowLockBasicTest.suite());
        suite.addTest(RecoveryTest.suite());
        suite.addTest(OCRecoveryTest.suite());
        suite.addTest(TableLockBasicTest.suite());
        suite.addTest(ServicePropertiesFileTest.suite());
        suite.addTest(Derby5234Test.suite());
        suite.addTest(KeepDisposableStatsPropertyTest.suite());
        suite.addTest(LockTableVtiTest.suite());
        suite.addTest(StoreScriptsTest.suite());
        suite.addTest(Derby4923Test.suite());
        suite.addTest(SpaceTableTest.suite());
        
        /* Tests that only run in sane builds */
        if (SanityManager.DEBUG) {
            suite.addTest(HoldCursorExternalSortJDBC30Test.suite());
        }

        // Encryption only supported for Derby in J2SE/J2EE environments.
        // J2ME (JSR169) does not support encryption.
        if (JDBC.vmSupportsJDBC3()) {
            // Add tests of basic functionality on encrypted databases.
            suite.addTest(EncryptionKeyAESTest.suite());
            suite.addTest(EncryptionKeyBlowfishTest.suite());
            suite.addTest(EncryptionKeyDESTest.suite());
            suite.addTest(EncryptionAESTest.suite());
            suite.addTest(EncryptDatabaseTest.suite());
            suite.addTest(CryptoCrashRecoveryTest.suite());
            suite.addTest(DecryptDatabaseTest.suite());
        }

        return suite;
    }
}
